@@ -3,7 +3,7 @@ package Test::Compile::Internal;
 use warnings;
 use strict;
 
-use version; our $VERSION = qv("v3.0.0");
+use version; our $VERSION = version->declare("v3.1.1");
 use File::Spec;
 use Test::Builder;
 use IPC::Open3 ();
@@ -85,7 +85,7 @@ sub all_pm_files_ok {
     my $ok = 1;
     for my $file ( $self->all_pm_files(@dirs) ) {
         my $testok = $self->pm_file_compiles($file);
-	$ok = $testok ? $ok : 0;
+        $ok = $testok ? $ok : 0;
         $test->ok($testok, "$file compiles");
     }
     return $ok;
@@ -109,7 +109,7 @@ sub all_pl_files_ok {
     my $ok = 1;
     for my $file ( $self->all_pl_files(@dirs) ) {
         my $testok = $self->pl_file_compiles($file);
-	$ok = $testok ? $ok : 0;
+        $ok = $testok ? $ok : 0;
         $test->ok($testok, "$file compiles");
     }
     return $ok;
@@ -144,8 +144,8 @@ extension.
 If you provide a list of C<@dirs>, it'll use that as a list of files to process, or
 directories to search for perl modules.
 
-If you don't provide C<dirs>, it'll search for perl modules in the F<blib> directory,
-unless that directory doesn't exist, in which case it'll search the F<lib> directory.
+If you don't provide C<dirs>, it'll search for perl modules in the F<blib/lib> directory,
+if that directory exists, otherwise it'll search the F<lib> directory.
 
 Skips any files in F<CVS>, F<.svn>, or F<.git> directories.
 
@@ -157,11 +157,13 @@ sorted, you'll have to sort them yourself.
 sub all_pm_files {
     my ($self, @dirs) = @_;
 
-    @dirs = @dirs ? @dirs : _pm_starting_points();
+    @dirs = @dirs ? @dirs : $self->_default_locations('lib');
 
     my @pm;
     for my $file ( $self->_find_files(@dirs) ) {
-        push @pm, $file if $file =~ /\.pm$/;
+        if ( $self->_perl_module($file) ) {
+            push @pm, $file;
+        }
     }
     return @pm;
 }
@@ -169,14 +171,14 @@ sub all_pm_files {
 =item C<all_pl_files(@dirs)>
 
 Searches for and returns a list of perl script files - that is, any files that either
-have a F<.pl> extension, or have no extension but have a perl shebang line.
+have a case insensitive F<.pl>, F<.psgi> extension, or have no extension but have a perl shebang line.
 
 If you provide a list of C<@dirs>, it'll use that as a list of files to process, or
 directories to search for perl scripts.
 
 If you don't provide C<dirs>, it'll search for perl scripts in the F<blib/script/> 
-directory, or if that doesn't exist, the F<script/> directory, or if that doesn't exist,
-the F<bin/> directory.
+and F<blib/bin/> directories if F<blib> exists, otherwise it'll search the F<script/>
+and F<bin/> directories
 
 Skips any files in F<CVS>, F<.svn>, or F<.git> directories.
 
@@ -188,21 +190,13 @@ sorted, you'll have to sort them yourself.
 sub all_pl_files {
     my ($self, @dirs) = @_;
 
-    @dirs = @dirs ? @dirs : _pl_starting_points();
+    @dirs = @dirs ? @dirs : $self->_default_locations('script', 'bin');
 
     my @pl;
     for my $file ( $self->_find_files(@dirs) ) {
-        if ( $file =~ /\.pl$/ ) {
-            # Files with a .pl extension are perl scripts
+        if ( $self->_perl_script($file) ) {
             push @pl, $file;
         }
-        elsif ( $file =~ /(?:^[^.]+$)/ ) {
-            # Files with no extension, but a perl shebang are perl scripts
-            my $shebang = $self->_read_shebang($file);
-            if ( $shebang =~ m/perl/ ) {
-                push @pl, $file;
-            }
-        }
     }
     return @pl;
 }
@@ -321,7 +315,7 @@ sub _run_command {
 
     my $output;
     for my $handle ( $stdout, $stderr ) {
-	if ( $handle ) {
+        if ( $handle ) {
             while ( my $line = <$handle> ) {
                 push @$output, $line;
             }
@@ -373,7 +367,7 @@ sub _perl_file_compiles {
     }
 
     my @inc = ('blib/lib', @INC);
-    my $taint = $self->_is_in_taint_mode($file);
+    my $taint = $self->_taint_mode($file);
     my $command = join(" ", (qq{"$^X"}, (map { qq{"-I$_"} } @inc), "-c$taint", $file));
     if ( $self->verbose() ) {
         $self->{test}->diag("Executing: " . $command);
@@ -390,17 +384,18 @@ sub _perl_file_compiles {
     return $compiles;
 }
 
-# Where do we expect to find perl modules?
-sub _pm_starting_points {
-    return 'blib' if -e 'blib';
-    return 'lib';
-}
+# Where do we expect to find perl files?
+sub _default_locations {
+    my ($self, @dirs) = @_;
 
-# Where do we expect to find perl programs?
-sub _pl_starting_points {
-    return 'blib/script' if -e 'blib/script';
-    return 'script' if -e 'script';
-    return 'bin'    if -e 'bin';
+    my @locations = ();
+    my $prefix = -e 'blib' ? "blib" : ".";
+    for my $dir ( @dirs ) {
+	if ( -e "$prefix/$dir" ) {
+            push @locations, "$prefix/$dir";
+        }
+    }
+    return @locations;
 }
 
 # Extract the shebang line from a perl program
@@ -415,7 +410,7 @@ sub _read_shebang {
 }
 
 # Should the given file be checked with taint mode on?
-sub _is_in_taint_mode {
+sub _taint_mode {
     my ($self, $file) = @_;
 
     my $shebang = $self->_read_shebang($file);
@@ -426,6 +421,33 @@ sub _is_in_taint_mode {
     return $taint;
 }
 
+# Does this file look like a perl script?
+sub _perl_script {
+    my ($self, $file) = @_;
+
+    # Files with .pl or .psgi extensions are perl scripts
+    if ( $file =~ /\.p(?:l|sgi)$/i ) {
+        return 1;
+    }
+
+    # Files with no extension, but a perl shebang are perl scripts
+    if ( $file =~ /(?:^[^.]+$)/ ) {
+        my $shebang = $self->_read_shebang($file);
+        if ( $shebang =~ m/perl/ ) {
+            return 1;
+        }
+    }
+}
+
+# Does this file look like a perl module?
+sub _perl_module {
+    my ($self, $file) = @_;
+
+    if ( $file =~ /\.pm$/ ) {
+        return 1;
+    }
+}
+
 1;
 
 =head1 AUTHORS
@@ -436,7 +458,7 @@ Evan Giles, C<< <egiles@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2021 by the authors.
+Copyright 2007-2023 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -446,4 +468,7 @@ it under the same terms as Perl itself.
 L<Test::Strict> provides functions to ensure your perl files compile, with
 the added bonus that it will check you have used strict in all your files.
 
+L<Test::LoadAllModules> just handles modules, not script files, but has more
+fine-grained control.
+
 =cut
